# NetSimR

NetSimR is an R package providing functions which are usually used in insurance
pricing, capital modelling and claims reserving, including:

- Capped mean
- Exposure curves from severity curves
- Increased limit factor curves from severity curves
- Sliced distribution functions
- Pure IBNR estimation from reporting delay distributions

Three shiny tools are also included in this package:
- Distribution fitting tool allows fitting claims distributions for frequency or severity.
- GLM fitting tool allows fitting different glm distributions.
- Claims simulation tool allows simulating fitted claims applying various reinsurance structures.
