% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LogNormal.R
\name{LNormCappedMean}
\alias{LNormCappedMean}
\title{Lognormal capped mean}
\usage{
LNormCappedMean(cap, mu, sigma)
}
\arguments{
\item{cap}{A positive real number -  the claim severity cap.}

\item{mu}{A real number - the first parameter of the Claim Severity's LogNormal distribution.}

\item{sigma}{A positive real number - the second parameter of the Claim Severity's LogNormal distribution.}
}
\value{
The mean of the claim severity capped at \code{cap} with a LogNormal distribution with parameters \code{mu} and \code{sigma}.
}
\description{
Lognormal capped mean
}
\examples{
LNormCappedMean(2000,6,1.5)
LNormCappedMean(1000,5,1.6)
}
