% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\name{reinsurance_structures_options}
\alias{reinsurance_structures_options}
\title{A vector with the reinsurance structure options}
\usage{
reinsurance_structures_options
}
\value{
The reinsurance structure options
}
\description{
A vector with the reinsurance structure options
}
