% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GLMFittingToolUI.R
\name{GLMFittingToolUI}
\alias{GLMFittingToolUI}
\title{UI file for the Shiny GLM fitting tool}
\usage{
GLMFittingToolUI
}
\value{
Returns the UI code for the shiny application.
}
\description{
UI file for the Shiny GLM fitting tool
}
