% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution_fitting_tool_Server.R
\name{distribution_fitting_tool_Server}
\alias{distribution_fitting_tool_Server}
\title{Server function for the Distribution Fitting tool application}
\usage{
distribution_fitting_tool_Server(input, output, session)
}
\arguments{
\item{input}{Input for the server function.}

\item{output}{Output for the server function.}

\item{session}{Session for the server function.}
}
\value{
Returns server rendering for the shiny application.
}
\description{
Server function for the Distribution Fitting tool application
}
