% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\name{run_shiny_simulator}
\alias{run_shiny_simulator}
\title{A function to run the shiny simulator application}
\usage{
run_shiny_simulator()
}
\value{
Opens the shiny simulator application
}
\description{
A function to run the shiny simulator application
}
