% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Gamma.R
\name{GammaCappedMean}
\alias{GammaCappedMean}
\title{Gamma capped mean}
\usage{
GammaCappedMean(cap, shape, rate)
}
\arguments{
\item{cap}{A positive real number -  the claim severity cap.}

\item{shape}{A positive real number - the shape parameter of the Claim Severity's Gamma distribution.}

\item{rate}{A positive real number - the rate parameter of the Claim Severity's Gamma distribution.}
}
\value{
The mean of the claim severity capped at \code{cap} with a Gamma distribution with parameters \code{shape} and \code{rate}.
}
\description{
Gamma capped mean
}
\examples{
GammaCappedMean(700,1,0.0005)
GammaCappedMean(1000,1.5,0.0006)
}
