% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GLMFittingToolGlobal.R
\name{run_shiny_glm_fitting_tool}
\alias{run_shiny_glm_fitting_tool}
\title{A function to run the glm fitting tool application}
\usage{
run_shiny_glm_fitting_tool()
}
\value{
Opens the glm fitting tool application
}
\description{
A function to run the glm fitting tool application
}
