% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Gamma.R
\name{ExposureCurveGamma}
\alias{ExposureCurveGamma}
\title{Exposure Curve from a Gamma severity distribution}
\usage{
ExposureCurveGamma(x, shape, rate)
}
\arguments{
\item{x}{A positive real number -  the claim amount where the exposure curve will be evaluated.}

\item{shape}{A positive real number - the shape parameter of the Claim Severity's Gamma distribution.}

\item{rate}{A positive real number - the rate parameter of the Claim Severity's Gamma distribution.}
}
\value{
The value of the Exposure curve at \code{x} with Claim Severity from a Gamma distribution with parameters \code{shape} and \code{rate}.
}
\description{
Exposure Curve from a Gamma severity distribution
}
\examples{
ExposureCurveGamma(700,1,0.0005)
ExposureCurveGamma(1000,1.5,0.0006)
}
