% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LogNormal.R
\name{erf}
\alias{erf}
\title{Error function}
\usage{
erf(x)
}
\arguments{
\item{x}{A real number.}
}
\value{
The value of the error function at \code{x}.
}
\description{
Error function
}
\examples{
erf(0.1)
erf(0.5)
}
