% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\name{max_number_of_pareto_slices}
\alias{max_number_of_pareto_slices}
\title{Parameter to set the maximum number of pareto slices}
\usage{
max_number_of_pareto_slices
}
\value{
The the maximum number of Pareto Slices.
}
\description{
Parameter to set the maximum number of pareto slices
}
