% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Pareto.R
\name{ExposureCurvePareto}
\alias{ExposureCurvePareto}
\title{Exposure Curve from a Pareto severity distribution}
\usage{
ExposureCurvePareto(x, scale, shape)
}
\arguments{
\item{x}{A positive real number -  the claim amount where the exposure curve will be evaluated.}

\item{scale}{A positive real number - the scale parameter of the Claim Severity's Pareto distribution.}

\item{shape}{A positive real number - the shape parameter of the Claim Severity's Pareto distribution.}
}
\value{
The value of the Exposure curve at \code{x} with Claim Severity from a Pareto distribution with parameters \code{scale} and \code{shape}.
}
\description{
Exposure Curve from a Pareto severity distribution
}
\examples{
ExposureCurvePareto(700,500,1.2)
ExposureCurvePareto(20000,200,1.1)
}
