% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Gamma.R
\name{IGamma}
\alias{IGamma}
\title{Lower incomplete gamma function}
\usage{
IGamma(a, x)
}
\arguments{
\item{a}{A positive real number.}

\item{x}{A positive real number.}
}
\value{
The value of the lower incomplete gamma function at \code{x} with shape parameter \code{a}.
}
\description{
Lower incomplete gamma function
}
\examples{
IGamma(1,1)
IGamma(0.1,2)
}
