% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorUI.R
\name{shiny_simulator_ui}
\alias{shiny_simulator_ui}
\title{UI file for the Shiny NetSimR Simulator Tool}
\usage{
shiny_simulator_ui
}
\value{
Returns the UI code for the shiny application.
}
\description{
UI file for the Shiny NetSimR Simulator Tool
}
