% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LogNormal.R
\name{ExposureCurveLNorm}
\alias{ExposureCurveLNorm}
\title{Exposure Curve from LogNormal a severity distribution}
\usage{
ExposureCurveLNorm(x, mu, sigma)
}
\arguments{
\item{x}{A positive real number -  the claim amount where the exposure curve will be evaluated.}

\item{mu}{A real number - the first parameter of the Claim Severity's LogNormal distribution.}

\item{sigma}{A positive real number - the second parameter of the Claim Severity's LogNormal distribution.}
}
\value{
The value of the Exposure curve at \code{x} with Claim Severity from a LogNormal distribution with parameters \code{mu} and \code{sigma}.
}
\description{
Exposure Curve from LogNormal a severity distribution
}
\examples{
ExposureCurveLNorm(2000,6,1.5)
ExposureCurveLNorm(1000,5,1.6)
}
