% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\name{freq_dist_options}
\alias{freq_dist_options}
\title{A vector with the frequency distribution objects}
\usage{
freq_dist_options
}
\value{
The frequency distribution objects.
}
\description{
A vector with the frequency distribution objects
}
