% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\name{freq_dist_parameter_placeholders}
\alias{freq_dist_parameter_placeholders}
\title{A data frame with the frequency distribution parameter placeholders}
\usage{
freq_dist_parameter_placeholders
}
\value{
The frequency distribution parameter placeholders.
}
\description{
A data frame with the frequency distribution parameter placeholders
}
