% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\name{sev_dist_parameter_placeholders}
\alias{sev_dist_parameter_placeholders}
\title{A data frame with the severity distribution parameter placeholders}
\usage{
sev_dist_parameter_placeholders
}
\value{
The severity distribution parameter placeholders.
}
\description{
A data frame with the severity distribution parameter placeholders
}
