% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\docType{class}
\name{distributionClass-class}
\alias{distributionClass-class}
\alias{distributionClass}
\title{The class of the distribution objects}
\description{
The class of the distribution objects
}
