% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\name{rpareto}
\alias{rpareto}
\title{Random Pareto generator}
\usage{
rpareto(n, alpha, x_m)
}
\arguments{
\item{n}{Number of values to generate.}

\item{alpha}{A positive real number. Alpha parameter of the Pareto distribution.}

\item{x_m}{A positive real number. The minimum value for the Pareto distribution.}
}
\value{
A vector of \code{n} random Pareto variables with parameters \code{alpha} and \code{x_m}.
}
\description{
Random Pareto generator
}
