% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorServer.R
\name{shiny_simulator_server}
\alias{shiny_simulator_server}
\title{Server function for the Shiny Simulator application}
\usage{
shiny_simulator_server(input, output, session)
}
\arguments{
\item{input}{Input for the server function.}

\item{output}{Output for the server function.}

\item{session}{Session for the server function.}
}
\value{
Returns server rendering for the shiny application.
}
\description{
Server function for the Shiny Simulator application
}
