% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution_fitting_tool_UI.R
\name{distribution_fitting_tool_UI}
\alias{distribution_fitting_tool_UI}
\title{UI file for the Shiny glm fitting tool}
\usage{
distribution_fitting_tool_UI
}
\value{
Returns the UI code for the shiny application.
}
\description{
UI file for the Shiny glm fitting tool
}
