% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Pareto.R
\name{ParetoCappedMeanCalc}
\alias{ParetoCappedMeanCalc}
\title{Pareto capped mean intermediary calculation}
\usage{
ParetoCappedMeanCalc(cap, scale, shape)
}
\arguments{
\item{cap}{A positive real number -  the claim severity cap.}

\item{scale}{A positive real number - the scale parameter of the Claim Severity's Pareto distribution.}

\item{shape}{A positive real number - the shape parameter of the Claim Severity's Pareto distribution.}
}
\value{
An interim calculation for the mean of the claim severity capped at \code{cap} with a Pareto distribution with parameters \code{scale} and \code{shape}.
}
\description{
Pareto capped mean intermediary calculation
}
\examples{
ParetoCappedMeanCalc(800,100,1.1)
ParetoCappedMeanCalc(1000,500,0.9)
}
