% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GLMFittingToolServer.R
\name{GLMFittingToolServer}
\alias{GLMFittingToolServer}
\title{Server function for the GLM Fitting tool application}
\usage{
GLMFittingToolServer(input, output, session)
}
\arguments{
\item{input}{Input for the server function.}

\item{output}{Output for the server function.}

\item{session}{Session for the server function.}
}
\value{
Returns server rendering for the shiny application.
}
\description{
Server function for the GLM Fitting tool application
}
