% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\name{sev_dist_options}
\alias{sev_dist_options}
\title{A vector with the severity distribution objects}
\usage{
sev_dist_options
}
\value{
The severity distribution objects.
}
\description{
A vector with the severity distribution objects
}
