% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ShinySimulatorGlobal.R
\name{apply_severity_cap}
\alias{apply_severity_cap}
\title{Apply severity cap function}
\usage{
apply_severity_cap(claims, severity_cap_boolean, severity_cap_amount)
}
\arguments{
\item{claims}{A vector of Claims.}

\item{severity_cap_boolean}{A variable that if true, the function will cap the claims, otherwise will just return them.}

\item{severity_cap_amount}{The claim cap value.}
}
\value{
If \code{severity_cap_boolean} is true, then will return the minimum of \code{severity_cap_amount} or \code{claims} otherwise will return \code{claims}. The operation is vectorised.
}
\description{
Apply severity cap function
}
